# intelligen


[![image](https://img.shields.io/pypi/v/intelligen.svg)](https://pypi.python.org/pypi/intelligen)


**This is a Python package for math and artificial intelligence tools**


-   Free software: MIT license
-   Documentation: https://Bouchet07.github.io/intelligen
    

## Features

-   TODO

## Credits

This package was created with [Cookiecutter](https://github.com/cookiecutter/cookiecutter) and the [giswqs/pypackage](https://github.com/giswqs/pypackage) project template.
